/*
 The software in this package is distributed under the GNU General
 Public License version 2 (with a special exception described below).

 A copy of GNU General Public License (GPL) is included in this distribution,
 in the file COPYING.GPL.

 As a special exception, if other files instantiate templates or use macros
 or inline functions from this file, or you compile this file and link it
 with other works to produce a work based on this file, this file
 does not by itself cause the resulting work to be covered
 by the GNU General Public License.

 However the source code for this file must still be made available
 in accordance with section (3) of the GNU General Public License.

 This exception does not invalidate any other reasons why a work based
 on this file might be covered by the GNU General Public License.
 */

#ifndef NETWORK_INTERFACE_LIST_H
#define NETWORK_INTERFACE_LIST_H

#include <ifaddrs.h>

#include <string>

typedef struct ifaddrs ifaddrs_t;

//-----------------------------------------------------------------------------
// NetworkInterfaceList
//-----------------------------------------------------------------------------

/**
 * @brief Represents the list of local network interfaces.
 */
class NetworkInterfaceList
{
public:
    NetworkInterfaceList();
    ~NetworkInterfaceList();

    const struct ifaddrs * find_interface(
            const std::string nic_name,
            const sa_family_t family
    );

private:
    // Do not allow copies of this object, cannot deep copy.
    NetworkInterfaceList( const NetworkInterfaceList &other );
    NetworkInterfaceList& operator=( const NetworkInterfaceList &other );

    bool initialized() const;
    bool create_list();
    void destroy_list();

private:
    ifaddrs_t *IfaFirst;
};

#endif // NETWORK_INTERFACE_LIST_H
